# Test Image

Simple markdown image:

![Test](assets/diagrams/methods_0.png)

HTML image:

<img src="assets/diagrams/methods_0.png" alt="test" style="width: 80%;">

Click-zoom div:

<div class="click-zoom" markdown="span">
  <label>
    <input type="checkbox">
    <img src="assets/diagrams/methods_0.png" alt="test" style="width: 80%;">
  </label>
</div>
